@@ -4,3 +4,7 @@ ORDER <- function(x, ...)
 ORDER.default <- function(x, ..., na.last = TRUE, decreasing = FALSE)
   order(x, ..., na.last = na.last, decreasing = decreasing)
 
+ORDER.timeDate <- function(x, ...) {
+  stopifnot(require("fCalendar"))
+  order(as.POSIXct(x), ...)
+}
